/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DrawingAreaMessages_h
#define DrawingAreaMessages_h

#include "Arguments.h"
#include "MessageEncoder.h"
#include "StringReference.h"

namespace WebCore {
    class FloatPoint;
    class IntSize;
    class FloatRect;
}

namespace WebKit {
    struct ColorSpaceData;
}

namespace Messages {
namespace DrawingArea {

static inline IPC::StringReference messageReceiverName()
{
    return IPC::StringReference("DrawingArea");
}

class UpdateBackingStoreState {
public:
    typedef std::tuple<uint64_t, bool, float, WebCore::IntSize, WebCore::IntSize> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("UpdateBackingStoreState"); }
    static const bool isSync = false;

    UpdateBackingStoreState(uint64_t backingStoreStateID, bool respondImmediately, float deviceScaleFactor, const WebCore::IntSize& size, const WebCore::IntSize& scrollOffset)
        : m_arguments(backingStoreStateID, respondImmediately, deviceScaleFactor, size, scrollOffset)
    {
    }

    const std::tuple<uint64_t, bool, float, const WebCore::IntSize&, const WebCore::IntSize&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool, float, const WebCore::IntSize&, const WebCore::IntSize&> m_arguments;
};

class DidUpdate {
public:
    typedef std::tuple<> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidUpdate"); }
    static const bool isSync = false;

    const std::tuple<> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

#if PLATFORM(MAC)
class UpdateGeometry {
public:
    typedef std::tuple<WebCore::IntSize, WebCore::IntSize> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("UpdateGeometry"); }
    static const bool isSync = false;

    UpdateGeometry(const WebCore::IntSize& viewSize, const WebCore::IntSize& layerPosition)
        : m_arguments(viewSize, layerPosition)
    {
    }

    const std::tuple<const WebCore::IntSize&, const WebCore::IntSize&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::IntSize&, const WebCore::IntSize&> m_arguments;
};
#endif

#if PLATFORM(MAC)
class SetDeviceScaleFactor {
public:
    typedef std::tuple<float> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("SetDeviceScaleFactor"); }
    static const bool isSync = false;

    explicit SetDeviceScaleFactor(float deviceScaleFactor)
        : m_arguments(deviceScaleFactor)
    {
    }

    const std::tuple<float> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<float> m_arguments;
};
#endif

#if PLATFORM(MAC)
class SetColorSpace {
public:
    typedef std::tuple<WebKit::ColorSpaceData> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("SetColorSpace"); }
    static const bool isSync = false;

    explicit SetColorSpace(const WebKit::ColorSpaceData& colorSpace)
        : m_arguments(colorSpace)
    {
    }

    const std::tuple<const WebKit::ColorSpaceData&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebKit::ColorSpaceData&> m_arguments;
};
#endif

#if PLATFORM(MAC)
class SetExposedRect {
public:
    typedef std::tuple<WebCore::FloatRect> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("SetExposedRect"); }
    static const bool isSync = false;

    explicit SetExposedRect(const WebCore::FloatRect& exposedRect)
        : m_arguments(exposedRect)
    {
    }

    const std::tuple<const WebCore::FloatRect&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::FloatRect&> m_arguments;
};
#endif

#if PLATFORM(MAC)
class SetCustomFixedPositionRect {
public:
    typedef std::tuple<WebCore::FloatRect> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("SetCustomFixedPositionRect"); }
    static const bool isSync = false;

    explicit SetCustomFixedPositionRect(const WebCore::FloatRect& fixedPositionRect)
        : m_arguments(fixedPositionRect)
    {
    }

    const std::tuple<const WebCore::FloatRect&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::FloatRect&> m_arguments;
};
#endif

#if PLATFORM(MAC)
class AdjustTransientZoom {
public:
    typedef std::tuple<double, WebCore::FloatPoint> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("AdjustTransientZoom"); }
    static const bool isSync = false;

    AdjustTransientZoom(double scale, const WebCore::FloatPoint& origin)
        : m_arguments(scale, origin)
    {
    }

    const std::tuple<double, const WebCore::FloatPoint&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<double, const WebCore::FloatPoint&> m_arguments;
};
#endif

#if PLATFORM(MAC)
class CommitTransientZoom {
public:
    typedef std::tuple<double, WebCore::FloatPoint> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("CommitTransientZoom"); }
    static const bool isSync = false;

    CommitTransientZoom(double scale, const WebCore::FloatPoint& origin)
        : m_arguments(scale, origin)
    {
    }

    const std::tuple<double, const WebCore::FloatPoint&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<double, const WebCore::FloatPoint&> m_arguments;
};
#endif

} // namespace DrawingArea
} // namespace Messages

#endif // DrawingAreaMessages_h
