/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include "WebPage.h"

#include "ArgumentCoders.h"
#if PLATFORM(MAC)
#include "AttributedString.h"
#endif
#include "DataReference.h"
#if PLATFORM(MAC) || PLATFORM(MAC) && !PLATFORM(IOS)
#include "EditorState.h"
#endif
#include "HandleMessage.h"
#if PLATFORM(IOS)
#include "InteractionInformationAtPosition.h"
#endif
#include "MessageDecoder.h"
#include "PrintInfo.h"
#include "SandboxExtension.h"
#include "SessionState.h"
#if PLATFORM(MAC)
#include "SharedMemory.h"
#endif
#if ENABLE(CONTEXT_MENUS)
#include "WebContextMenuItemData.h"
#endif
#include "WebContextUserMessageCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebEvent.h"
#include "WebPageMessages.h"
#include "WebPreferencesStore.h"
#include <WebCore/Color.h>
#if PLATFORM(MAC)
#include <WebCore/DictationAlternative.h>
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include <WebCore/DragData.h>
#endif
#if PLATFORM(EFL) || PLATFORM(GTK) || PLATFORM(IOS) || PLATFORM(MAC) && !PLATFORM(IOS)
#include <WebCore/Editor.h>
#endif
#if PLATFORM(MAC) || PLATFORM(IOS)
#include <WebCore/FloatPoint.h>
#endif
#if PLATFORM(MAC)
#include <WebCore/FloatRect.h>
#endif
#include <WebCore/IntPoint.h>
#if PLATFORM(MAC)
#include <WebCore/IntRect.h>
#endif
#include <WebCore/IntSize.h>
#if PLATFORM(MAC)
#include <WebCore/KeyboardEvent.h>
#endif
#include <WebCore/ResourceRequest.h>
#include <WebCore/TextCheckerClient.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WebKit {

void WebPage::didReceiveWebPageMessage(IPC::Connection*, IPC::MessageDecoder& decoder)
{
    if (decoder.messageName() == Messages::WebPage::SetInitialFocus::name()) {
        IPC::handleMessage<Messages::WebPage::SetInitialFocus>(decoder, this, &WebPage::setInitialFocus);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetViewState::name()) {
        IPC::handleMessage<Messages::WebPage::SetViewState>(decoder, this, &WebPage::setViewState);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetLayerHostingMode::name()) {
        IPC::handleMessage<Messages::WebPage::SetLayerHostingMode>(decoder, this, &WebPage::setLayerHostingMode);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetSessionID::name()) {
        IPC::handleMessage<Messages::WebPage::SetSessionID>(decoder, this, &WebPage::setSessionID);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetDrawsBackground::name()) {
        IPC::handleMessage<Messages::WebPage::SetDrawsBackground>(decoder, this, &WebPage::setDrawsBackground);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetDrawsTransparentBackground::name()) {
        IPC::handleMessage<Messages::WebPage::SetDrawsTransparentBackground>(decoder, this, &WebPage::setDrawsTransparentBackground);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetUnderlayColor::name()) {
        IPC::handleMessage<Messages::WebPage::SetUnderlayColor>(decoder, this, &WebPage::setUnderlayColor);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ViewWillStartLiveResize::name()) {
        IPC::handleMessage<Messages::WebPage::ViewWillStartLiveResize>(decoder, this, &WebPage::viewWillStartLiveResize);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ViewWillEndLiveResize::name()) {
        IPC::handleMessage<Messages::WebPage::ViewWillEndLiveResize>(decoder, this, &WebPage::viewWillEndLiveResize);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::KeyEvent::name()) {
        IPC::handleMessage<Messages::WebPage::KeyEvent>(decoder, this, &WebPage::keyEvent);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::MouseEvent::name()) {
        IPC::handleMessage<Messages::WebPage::MouseEvent>(decoder, this, &WebPage::mouseEvent);
        return;
    }
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::HandleTap::name()) {
        IPC::handleMessage<Messages::WebPage::HandleTap>(decoder, this, &WebPage::handleTap);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::TapHighlightAtPosition::name()) {
        IPC::handleMessage<Messages::WebPage::TapHighlightAtPosition>(decoder, this, &WebPage::tapHighlightAtPosition);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::BlurAssistedNode::name()) {
        IPC::handleMessage<Messages::WebPage::BlurAssistedNode>(decoder, this, &WebPage::blurAssistedNode);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::SelectWithGesture::name()) {
        IPC::handleMessage<Messages::WebPage::SelectWithGesture>(decoder, this, &WebPage::selectWithGesture);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::UpdateSelectionWithTouches::name()) {
        IPC::handleMessage<Messages::WebPage::UpdateSelectionWithTouches>(decoder, this, &WebPage::updateSelectionWithTouches);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::SelectWithTwoTouches::name()) {
        IPC::handleMessage<Messages::WebPage::SelectWithTwoTouches>(decoder, this, &WebPage::selectWithTwoTouches);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::ExtendSelection::name()) {
        IPC::handleMessage<Messages::WebPage::ExtendSelection>(decoder, this, &WebPage::extendSelection);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::RequestAutocorrectionData::name()) {
        IPC::handleMessage<Messages::WebPage::RequestAutocorrectionData>(decoder, this, &WebPage::requestAutocorrectionData);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::ApplyAutocorrection::name()) {
        IPC::handleMessage<Messages::WebPage::ApplyAutocorrection>(decoder, this, &WebPage::applyAutocorrection);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::RequestAutocorrectionContext::name()) {
        IPC::handleMessage<Messages::WebPage::RequestAutocorrectionContext>(decoder, this, &WebPage::requestAutocorrectionContext);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::InsertText::name()) {
        IPC::handleMessage<Messages::WebPage::InsertText>(decoder, this, &WebPage::insertText);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::SetComposition::name()) {
        IPC::handleMessage<Messages::WebPage::SetComposition>(decoder, this, &WebPage::setComposition);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::ConfirmComposition::name()) {
        IPC::handleMessage<Messages::WebPage::ConfirmComposition>(decoder, this, &WebPage::confirmComposition);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::RequestPositionInformation::name()) {
        IPC::handleMessage<Messages::WebPage::RequestPositionInformation>(decoder, this, &WebPage::requestPositionInformation);
        return;
    }
#endif
#if ENABLE(TOUCH_EVENTS)
    if (decoder.messageName() == Messages::WebPage::TouchEvent::name()) {
        IPC::handleMessage<Messages::WebPage::TouchEvent>(decoder, this, &WebPage::touchEvent);
        return;
    }
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    if (decoder.messageName() == Messages::WebPage::DidEndColorPicker::name()) {
        IPC::handleMessage<Messages::WebPage::DidEndColorPicker>(decoder, this, &WebPage::didEndColorPicker);
        return;
    }
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    if (decoder.messageName() == Messages::WebPage::DidChooseColor::name()) {
        IPC::handleMessage<Messages::WebPage::DidChooseColor>(decoder, this, &WebPage::didChooseColor);
        return;
    }
#endif
#if ENABLE(CONTEXT_MENUS)
    if (decoder.messageName() == Messages::WebPage::ContextMenuHidden::name()) {
        IPC::handleMessage<Messages::WebPage::ContextMenuHidden>(decoder, this, &WebPage::contextMenuHidden);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::ScrollBy::name()) {
        IPC::handleMessage<Messages::WebPage::ScrollBy>(decoder, this, &WebPage::scrollBy);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::CenterSelectionInVisibleArea::name()) {
        IPC::handleMessage<Messages::WebPage::CenterSelectionInVisibleArea>(decoder, this, &WebPage::centerSelectionInVisibleArea);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GoBack::name()) {
        IPC::handleMessage<Messages::WebPage::GoBack>(decoder, this, &WebPage::goBack);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GoForward::name()) {
        IPC::handleMessage<Messages::WebPage::GoForward>(decoder, this, &WebPage::goForward);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GoToBackForwardItem::name()) {
        IPC::handleMessage<Messages::WebPage::GoToBackForwardItem>(decoder, this, &WebPage::goToBackForwardItem);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::TryRestoreScrollPosition::name()) {
        IPC::handleMessage<Messages::WebPage::TryRestoreScrollPosition>(decoder, this, &WebPage::tryRestoreScrollPosition);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadURLInFrame::name()) {
        IPC::handleMessage<Messages::WebPage::LoadURLInFrame>(decoder, this, &WebPage::loadURLInFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadRequest::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadRequest>(decoder, this, &WebPage::loadRequest);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadData::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadData>(decoder, this, &WebPage::loadData);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadHTMLString::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadHTMLString>(decoder, this, &WebPage::loadHTMLString);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadAlternateHTMLString::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadAlternateHTMLString>(decoder, this, &WebPage::loadAlternateHTMLString);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadPlainTextString::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadPlainTextString>(decoder, this, &WebPage::loadPlainTextString);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::LoadWebArchiveData::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::LoadWebArchiveData>(decoder, this, &WebPage::loadWebArchiveData);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::Reload::name()) {
        IPC::handleMessage<Messages::WebPage::Reload>(decoder, this, &WebPage::reload);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::StopLoading::name()) {
        IPC::handleMessage<Messages::WebPage::StopLoading>(decoder, this, &WebPage::stopLoading);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::StopLoadingFrame::name()) {
        IPC::handleMessage<Messages::WebPage::StopLoadingFrame>(decoder, this, &WebPage::stopLoadingFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::RestoreSession::name()) {
        IPC::handleMessage<Messages::WebPage::RestoreSession>(decoder, this, &WebPage::restoreSession);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::RestoreSessionAndNavigateToCurrentItem::name()) {
        IPC::handleMessage<Messages::WebPage::RestoreSessionAndNavigateToCurrentItem>(decoder, this, &WebPage::restoreSessionAndNavigateToCurrentItem);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidRemoveBackForwardItem::name()) {
        IPC::handleMessage<Messages::WebPage::DidRemoveBackForwardItem>(decoder, this, &WebPage::didRemoveBackForwardItem);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidReceivePolicyDecision::name()) {
        IPC::handleMessage<Messages::WebPage::DidReceivePolicyDecision>(decoder, this, &WebPage::didReceivePolicyDecision);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ClearSelection::name()) {
        IPC::handleMessage<Messages::WebPage::ClearSelection>(decoder, this, &WebPage::clearSelection);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetContentsAsString::name()) {
        IPC::handleMessage<Messages::WebPage::GetContentsAsString>(decoder, this, &WebPage::getContentsAsString);
        return;
    }
#if ENABLE(MHTML)
    if (decoder.messageName() == Messages::WebPage::GetContentsAsMHTMLData::name()) {
        IPC::handleMessage<Messages::WebPage::GetContentsAsMHTMLData>(decoder, this, &WebPage::getContentsAsMHTMLData);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::GetMainResourceDataOfFrame::name()) {
        IPC::handleMessage<Messages::WebPage::GetMainResourceDataOfFrame>(decoder, this, &WebPage::getMainResourceDataOfFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetResourceDataFromFrame::name()) {
        IPC::handleMessage<Messages::WebPage::GetResourceDataFromFrame>(decoder, this, &WebPage::getResourceDataFromFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetRenderTreeExternalRepresentation::name()) {
        IPC::handleMessage<Messages::WebPage::GetRenderTreeExternalRepresentation>(decoder, this, &WebPage::getRenderTreeExternalRepresentation);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetSelectionOrContentsAsString::name()) {
        IPC::handleMessage<Messages::WebPage::GetSelectionOrContentsAsString>(decoder, this, &WebPage::getSelectionOrContentsAsString);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetSelectionAsWebArchiveData::name()) {
        IPC::handleMessage<Messages::WebPage::GetSelectionAsWebArchiveData>(decoder, this, &WebPage::getSelectionAsWebArchiveData);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetSourceForFrame::name()) {
        IPC::handleMessage<Messages::WebPage::GetSourceForFrame>(decoder, this, &WebPage::getSourceForFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetWebArchiveOfFrame::name()) {
        IPC::handleMessage<Messages::WebPage::GetWebArchiveOfFrame>(decoder, this, &WebPage::getWebArchiveOfFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::RunJavaScriptInMainFrame::name()) {
        IPC::handleMessage<Messages::WebPage::RunJavaScriptInMainFrame>(decoder, this, &WebPage::runJavaScriptInMainFrame);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ForceRepaint::name()) {
        IPC::handleMessage<Messages::WebPage::ForceRepaint>(decoder, this, &WebPage::forceRepaint);
        return;
    }
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::PerformDictionaryLookupAtLocation::name()) {
        IPC::handleMessage<Messages::WebPage::PerformDictionaryLookupAtLocation>(decoder, this, &WebPage::performDictionaryLookupAtLocation);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::PreferencesDidChange::name()) {
        IPC::handleMessage<Messages::WebPage::PreferencesDidChange>(decoder, this, &WebPage::preferencesDidChange);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetUserAgent::name()) {
        IPC::handleMessage<Messages::WebPage::SetUserAgent>(decoder, this, &WebPage::setUserAgent);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetCustomTextEncodingName::name()) {
        IPC::handleMessage<Messages::WebPage::SetCustomTextEncodingName>(decoder, this, &WebPage::setCustomTextEncodingName);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SuspendActiveDOMObjectsAndAnimations::name()) {
        IPC::handleMessage<Messages::WebPage::SuspendActiveDOMObjectsAndAnimations>(decoder, this, &WebPage::suspendActiveDOMObjectsAndAnimations);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ResumeActiveDOMObjectsAndAnimations::name()) {
        IPC::handleMessage<Messages::WebPage::ResumeActiveDOMObjectsAndAnimations>(decoder, this, &WebPage::resumeActiveDOMObjectsAndAnimations);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::Close::name()) {
        IPC::handleMessage<Messages::WebPage::Close>(decoder, this, &WebPage::close);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::TryClose::name()) {
        IPC::handleMessage<Messages::WebPage::TryClose>(decoder, this, &WebPage::tryClose);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ValidateCommand::name()) {
        IPC::handleMessage<Messages::WebPage::ValidateCommand>(decoder, this, &WebPage::validateCommand);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ExecuteEditCommand::name()) {
        IPC::handleMessage<Messages::WebPage::ExecuteEditCommand>(decoder, this, &WebPage::executeEditCommand);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidRemoveEditCommand::name()) {
        IPC::handleMessage<Messages::WebPage::DidRemoveEditCommand>(decoder, this, &WebPage::didRemoveEditCommand);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ReapplyEditCommand::name()) {
        IPC::handleMessage<Messages::WebPage::ReapplyEditCommand>(decoder, this, &WebPage::reapplyEditCommand);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::UnapplyEditCommand::name()) {
        IPC::handleMessage<Messages::WebPage::UnapplyEditCommand>(decoder, this, &WebPage::unapplyEditCommand);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetPageAndTextZoomFactors::name()) {
        IPC::handleMessage<Messages::WebPage::SetPageAndTextZoomFactors>(decoder, this, &WebPage::setPageAndTextZoomFactors);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetPageZoomFactor::name()) {
        IPC::handleMessage<Messages::WebPage::SetPageZoomFactor>(decoder, this, &WebPage::setPageZoomFactor);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetTextZoomFactor::name()) {
        IPC::handleMessage<Messages::WebPage::SetTextZoomFactor>(decoder, this, &WebPage::setTextZoomFactor);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::WindowScreenDidChange::name()) {
        IPC::handleMessage<Messages::WebPage::WindowScreenDidChange>(decoder, this, &WebPage::windowScreenDidChange);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ScalePage::name()) {
        IPC::handleMessage<Messages::WebPage::ScalePage>(decoder, this, &WebPage::scalePage);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetUseFixedLayout::name()) {
        IPC::handleMessage<Messages::WebPage::SetUseFixedLayout>(decoder, this, &WebPage::setUseFixedLayout);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetFixedLayoutSize::name()) {
        IPC::handleMessage<Messages::WebPage::SetFixedLayoutSize>(decoder, this, &WebPage::setFixedLayoutSize);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ListenForLayoutMilestones::name()) {
        IPC::handleMessage<Messages::WebPage::ListenForLayoutMilestones>(decoder, this, &WebPage::listenForLayoutMilestones);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetSuppressScrollbarAnimations::name()) {
        IPC::handleMessage<Messages::WebPage::SetSuppressScrollbarAnimations>(decoder, this, &WebPage::setSuppressScrollbarAnimations);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetBackgroundExtendsBeyondPage::name()) {
        IPC::handleMessage<Messages::WebPage::SetBackgroundExtendsBeyondPage>(decoder, this, &WebPage::setBackgroundExtendsBeyondPage);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetPaginationMode::name()) {
        IPC::handleMessage<Messages::WebPage::SetPaginationMode>(decoder, this, &WebPage::setPaginationMode);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetPaginationBehavesLikeColumns::name()) {
        IPC::handleMessage<Messages::WebPage::SetPaginationBehavesLikeColumns>(decoder, this, &WebPage::setPaginationBehavesLikeColumns);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetPageLength::name()) {
        IPC::handleMessage<Messages::WebPage::SetPageLength>(decoder, this, &WebPage::setPageLength);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetGapBetweenPages::name()) {
        IPC::handleMessage<Messages::WebPage::SetGapBetweenPages>(decoder, this, &WebPage::setGapBetweenPages);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::PostInjectedBundleMessage::name()) {
        IPC::handleMessageVariadic<Messages::WebPage::PostInjectedBundleMessage>(decoder, this, &WebPage::postInjectedBundleMessage);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::FindString::name()) {
        IPC::handleMessage<Messages::WebPage::FindString>(decoder, this, &WebPage::findString);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::FindStringMatches::name()) {
        IPC::handleMessage<Messages::WebPage::FindStringMatches>(decoder, this, &WebPage::findStringMatches);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::GetImageForFindMatch::name()) {
        IPC::handleMessage<Messages::WebPage::GetImageForFindMatch>(decoder, this, &WebPage::getImageForFindMatch);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SelectFindMatch::name()) {
        IPC::handleMessage<Messages::WebPage::SelectFindMatch>(decoder, this, &WebPage::selectFindMatch);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::HideFindUI::name()) {
        IPC::handleMessage<Messages::WebPage::HideFindUI>(decoder, this, &WebPage::hideFindUI);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::CountStringMatches::name()) {
        IPC::handleMessage<Messages::WebPage::CountStringMatches>(decoder, this, &WebPage::countStringMatches);
        return;
    }
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    if (decoder.messageName() == Messages::WebPage::PerformDragControllerAction::name()) {
        IPC::handleMessage<Messages::WebPage::PerformDragControllerAction>(decoder, this, &WebPage::performDragControllerAction);
        return;
    }
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    if (decoder.messageName() == Messages::WebPage::PerformDragControllerAction::name()) {
        IPC::handleMessage<Messages::WebPage::PerformDragControllerAction>(decoder, this, &WebPage::performDragControllerAction);
        return;
    }
#endif
#if ENABLE(DRAG_SUPPORT)
    if (decoder.messageName() == Messages::WebPage::DragEnded::name()) {
        IPC::handleMessage<Messages::WebPage::DragEnded>(decoder, this, &WebPage::dragEnded);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::DidChangeSelectedIndexForActivePopupMenu::name()) {
        IPC::handleMessage<Messages::WebPage::DidChangeSelectedIndexForActivePopupMenu>(decoder, this, &WebPage::didChangeSelectedIndexForActivePopupMenu);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetTextForActivePopupMenu::name()) {
        IPC::handleMessage<Messages::WebPage::SetTextForActivePopupMenu>(decoder, this, &WebPage::setTextForActivePopupMenu);
        return;
    }
#if PLATFORM(GTK)
    if (decoder.messageName() == Messages::WebPage::FailedToShowPopupMenu::name()) {
        IPC::handleMessage<Messages::WebPage::FailedToShowPopupMenu>(decoder, this, &WebPage::failedToShowPopupMenu);
        return;
    }
#endif
#if ENABLE(CONTEXT_MENUS)
    if (decoder.messageName() == Messages::WebPage::DidSelectItemFromActiveContextMenu::name()) {
        IPC::handleMessage<Messages::WebPage::DidSelectItemFromActiveContextMenu>(decoder, this, &WebPage::didSelectItemFromActiveContextMenu);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::DidChooseFilesForOpenPanel::name()) {
        IPC::handleMessage<Messages::WebPage::DidChooseFilesForOpenPanel>(decoder, this, &WebPage::didChooseFilesForOpenPanel);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidCancelForOpenPanel::name()) {
        IPC::handleMessage<Messages::WebPage::DidCancelForOpenPanel>(decoder, this, &WebPage::didCancelForOpenPanel);
        return;
    }
#if ENABLE(WEB_PROCESS_SANDBOX)
    if (decoder.messageName() == Messages::WebPage::ExtendSandboxForFileFromOpenPanel::name()) {
        IPC::handleMessage<Messages::WebPage::ExtendSandboxForFileFromOpenPanel>(decoder, this, &WebPage::extendSandboxForFileFromOpenPanel);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::AdvanceToNextMisspelling::name()) {
        IPC::handleMessage<Messages::WebPage::AdvanceToNextMisspelling>(decoder, this, &WebPage::advanceToNextMisspelling);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ChangeSpellingToWord::name()) {
        IPC::handleMessage<Messages::WebPage::ChangeSpellingToWord>(decoder, this, &WebPage::changeSpellingToWord);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidFinishCheckingText::name()) {
        IPC::handleMessage<Messages::WebPage::DidFinishCheckingText>(decoder, this, &WebPage::didFinishCheckingText);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::DidCancelCheckingText::name()) {
        IPC::handleMessage<Messages::WebPage::DidCancelCheckingText>(decoder, this, &WebPage::didCancelCheckingText);
        return;
    }
#if USE(APPKIT)
    if (decoder.messageName() == Messages::WebPage::UppercaseWord::name()) {
        IPC::handleMessage<Messages::WebPage::UppercaseWord>(decoder, this, &WebPage::uppercaseWord);
        return;
    }
#endif
#if USE(APPKIT)
    if (decoder.messageName() == Messages::WebPage::LowercaseWord::name()) {
        IPC::handleMessage<Messages::WebPage::LowercaseWord>(decoder, this, &WebPage::lowercaseWord);
        return;
    }
#endif
#if USE(APPKIT)
    if (decoder.messageName() == Messages::WebPage::CapitalizeWord::name()) {
        IPC::handleMessage<Messages::WebPage::CapitalizeWord>(decoder, this, &WebPage::capitalizeWord);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::SetSmartInsertDeleteEnabled::name()) {
        IPC::handleMessage<Messages::WebPage::SetSmartInsertDeleteEnabled>(decoder, this, &WebPage::setSmartInsertDeleteEnabled);
        return;
    }
#endif
#if ENABLE(GEOLOCATION)
    if (decoder.messageName() == Messages::WebPage::DidReceiveGeolocationPermissionDecision::name()) {
        IPC::handleMessage<Messages::WebPage::DidReceiveGeolocationPermissionDecision>(decoder, this, &WebPage::didReceiveGeolocationPermissionDecision);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::DidReceiveNotificationPermissionDecision::name()) {
        IPC::handleMessage<Messages::WebPage::DidReceiveNotificationPermissionDecision>(decoder, this, &WebPage::didReceiveNotificationPermissionDecision);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetWindowResizerSize::name()) {
        IPC::handleMessage<Messages::WebPage::SetWindowResizerSize>(decoder, this, &WebPage::setWindowResizerSize);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::BeginPrinting::name()) {
        IPC::handleMessage<Messages::WebPage::BeginPrinting>(decoder, this, &WebPage::beginPrinting);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::EndPrinting::name()) {
        IPC::handleMessage<Messages::WebPage::EndPrinting>(decoder, this, &WebPage::endPrinting);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::ComputePagesForPrinting::name()) {
        IPC::handleMessage<Messages::WebPage::ComputePagesForPrinting>(decoder, this, &WebPage::computePagesForPrinting);
        return;
    }
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::DrawRectToImage::name()) {
        IPC::handleMessage<Messages::WebPage::DrawRectToImage>(decoder, this, &WebPage::drawRectToImage);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::DrawPagesToPDF::name()) {
        IPC::handleMessage<Messages::WebPage::DrawPagesToPDF>(decoder, this, &WebPage::drawPagesToPDF);
        return;
    }
#endif
#if PLATFORM(GTK)
    if (decoder.messageName() == Messages::WebPage::DrawPagesForPrinting::name()) {
        IPC::handleMessage<Messages::WebPage::DrawPagesForPrinting>(decoder, this, &WebPage::drawPagesForPrinting);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::SetMediaVolume::name()) {
        IPC::handleMessage<Messages::WebPage::SetMediaVolume>(decoder, this, &WebPage::setMediaVolume);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetMayStartMediaWhenInWindow::name()) {
        IPC::handleMessage<Messages::WebPage::SetMayStartMediaWhenInWindow>(decoder, this, &WebPage::setMayStartMediaWhenInWindow);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetMemoryCacheMessagesEnabled::name()) {
        IPC::handleMessage<Messages::WebPage::SetMemoryCacheMessagesEnabled>(decoder, this, &WebPage::setMemoryCacheMessagesEnabled);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetCanRunBeforeUnloadConfirmPanel::name()) {
        IPC::handleMessage<Messages::WebPage::SetCanRunBeforeUnloadConfirmPanel>(decoder, this, &WebPage::setCanRunBeforeUnloadConfirmPanel);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetCanRunModal::name()) {
        IPC::handleMessage<Messages::WebPage::SetCanRunModal>(decoder, this, &WebPage::setCanRunModal);
        return;
    }
#if PLATFORM(EFL)
    if (decoder.messageName() == Messages::WebPage::SetThemePath::name()) {
        IPC::handleMessage<Messages::WebPage::SetThemePath>(decoder, this, &WebPage::setThemePath);
        return;
    }
#endif
#if USE(TILED_BACKING_STORE)
    if (decoder.messageName() == Messages::WebPage::CommitPageTransitionViewport::name()) {
        IPC::handleMessage<Messages::WebPage::CommitPageTransitionViewport>(decoder, this, &WebPage::commitPageTransitionViewport);
        return;
    }
#endif
#if PLATFORM(GTK)
    if (decoder.messageName() == Messages::WebPage::SetComposition::name()) {
        IPC::handleMessage<Messages::WebPage::SetComposition>(decoder, this, &WebPage::setComposition);
        return;
    }
#endif
#if PLATFORM(GTK)
    if (decoder.messageName() == Messages::WebPage::ConfirmComposition::name()) {
        IPC::handleMessage<Messages::WebPage::ConfirmComposition>(decoder, this, &WebPage::confirmComposition);
        return;
    }
#endif
#if PLATFORM(GTK)
    if (decoder.messageName() == Messages::WebPage::CancelComposition::name()) {
        IPC::handleMessage<Messages::WebPage::CancelComposition>(decoder, this, &WebPage::cancelComposition);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::SendComplexTextInputToPlugin::name()) {
        IPC::handleMessage<Messages::WebPage::SendComplexTextInputToPlugin>(decoder, this, &WebPage::sendComplexTextInputToPlugin);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::WindowAndViewFramesChanged::name()) {
        IPC::handleMessage<Messages::WebPage::WindowAndViewFramesChanged>(decoder, this, &WebPage::windowAndViewFramesChanged);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::SetMainFrameIsScrollable::name()) {
        IPC::handleMessage<Messages::WebPage::SetMainFrameIsScrollable>(decoder, this, &WebPage::setMainFrameIsScrollable);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::RegisterUIProcessAccessibilityTokens::name()) {
        IPC::handleMessage<Messages::WebPage::RegisterUIProcessAccessibilityTokens>(decoder, this, &WebPage::registerUIProcessAccessibilityTokens);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::SetMinimumLayoutSize::name()) {
        IPC::handleMessage<Messages::WebPage::SetMinimumLayoutSize>(decoder, this, &WebPage::setMinimumLayoutSize);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetAutoSizingShouldExpandToViewHeight::name()) {
        IPC::handleMessage<Messages::WebPage::SetAutoSizingShouldExpandToViewHeight>(decoder, this, &WebPage::setAutoSizingShouldExpandToViewHeight);
        return;
    }
#if PLATFORM(EFL)
    if (decoder.messageName() == Messages::WebPage::ConfirmComposition::name()) {
        IPC::handleMessage<Messages::WebPage::ConfirmComposition>(decoder, this, &WebPage::confirmComposition);
        return;
    }
#endif
#if PLATFORM(EFL)
    if (decoder.messageName() == Messages::WebPage::SetComposition::name()) {
        IPC::handleMessage<Messages::WebPage::SetComposition>(decoder, this, &WebPage::setComposition);
        return;
    }
#endif
#if PLATFORM(EFL)
    if (decoder.messageName() == Messages::WebPage::CancelComposition::name()) {
        IPC::handleMessage<Messages::WebPage::CancelComposition>(decoder, this, &WebPage::cancelComposition);
        return;
    }
#endif
#if USE(COORDINATED_GRAPHICS)
    if (decoder.messageName() == Messages::WebPage::FindZoomableAreaForPoint::name()) {
        IPC::handleMessage<Messages::WebPage::FindZoomableAreaForPoint>(decoder, this, &WebPage::findZoomableAreaForPoint);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::HandleAlternativeTextUIResult::name()) {
        IPC::handleMessage<Messages::WebPage::HandleAlternativeTextUIResult>(decoder, this, &WebPage::handleAlternativeTextUIResult);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::SetVisibilityStatePrerender::name()) {
        IPC::handleMessage<Messages::WebPage::SetVisibilityStatePrerender>(decoder, this, &WebPage::setVisibilityStatePrerender);
        return;
    }
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::DidFinishScrolling::name()) {
        IPC::handleMessage<Messages::WebPage::DidFinishScrolling>(decoder, this, &WebPage::didFinishScrolling);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::DidFinishZooming::name()) {
        IPC::handleMessage<Messages::WebPage::DidFinishZooming>(decoder, this, &WebPage::didFinishZooming);
        return;
    }
#endif
#if PLATFORM(GTK) && USE(TEXTURE_MAPPER_GL)
    if (decoder.messageName() == Messages::WebPage::SetAcceleratedCompositingWindowId::name()) {
        IPC::handleMessage<Messages::WebPage::SetAcceleratedCompositingWindowId>(decoder, this, &WebPage::setAcceleratedCompositingWindowId);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::SetMainFrameInViewSourceMode::name()) {
        IPC::handleMessage<Messages::WebPage::SetMainFrameInViewSourceMode>(decoder, this, &WebPage::setMainFrameInViewSourceMode);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::SetScrollPinningBehavior::name()) {
        IPC::handleMessage<Messages::WebPage::SetScrollPinningBehavior>(decoder, this, &WebPage::setScrollPinningBehavior);
        return;
    }
    ASSERT_NOT_REACHED();
}

void WebPage::didReceiveSyncWebPageMessage(IPC::Connection*, IPC::MessageDecoder& decoder, std::unique_ptr<IPC::MessageEncoder>& replyEncoder)
{
    if (decoder.messageName() == Messages::WebPage::KeyEventSyncForTesting::name()) {
        IPC::handleMessage<Messages::WebPage::KeyEventSyncForTesting>(decoder, *replyEncoder, this, &WebPage::keyEventSyncForTesting);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::MouseEventSyncForTesting::name()) {
        IPC::handleMessage<Messages::WebPage::MouseEventSyncForTesting>(decoder, *replyEncoder, this, &WebPage::mouseEventSyncForTesting);
        return;
    }
    if (decoder.messageName() == Messages::WebPage::WheelEventSyncForTesting::name()) {
        IPC::handleMessage<Messages::WebPage::WheelEventSyncForTesting>(decoder, *replyEncoder, this, &WebPage::wheelEventSyncForTesting);
        return;
    }
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::GetAutocorrectionContext::name()) {
        IPC::handleMessage<Messages::WebPage::GetAutocorrectionContext>(decoder, *replyEncoder, this, &WebPage::getAutocorrectionContext);
        return;
    }
#endif
#if PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::GetPositionInformation::name()) {
        IPC::handleMessage<Messages::WebPage::GetPositionInformation>(decoder, *replyEncoder, this, &WebPage::getPositionInformation);
        return;
    }
#endif
#if ENABLE(TOUCH_EVENTS)
    if (decoder.messageName() == Messages::WebPage::TouchEventSyncForTesting::name()) {
        IPC::handleMessage<Messages::WebPage::TouchEventSyncForTesting>(decoder, *replyEncoder, this, &WebPage::touchEventSyncForTesting);
        return;
    }
#endif
    if (decoder.messageName() == Messages::WebPage::Dummy::name()) {
        IPC::handleMessage<Messages::WebPage::Dummy>(decoder, *replyEncoder, this, &WebPage::dummy);
        return;
    }
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::GetStringSelectionForPasteboard::name()) {
        IPC::handleMessage<Messages::WebPage::GetStringSelectionForPasteboard>(decoder, *replyEncoder, this, &WebPage::getStringSelectionForPasteboard);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::GetDataSelectionForPasteboard::name()) {
        IPC::handleMessage<Messages::WebPage::GetDataSelectionForPasteboard>(decoder, *replyEncoder, this, &WebPage::getDataSelectionForPasteboard);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::ReadSelectionFromPasteboard::name()) {
        IPC::handleMessage<Messages::WebPage::ReadSelectionFromPasteboard>(decoder, *replyEncoder, this, &WebPage::readSelectionFromPasteboard);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::CancelComposition::name()) {
        IPC::handleMessage<Messages::WebPage::CancelComposition>(decoder, *replyEncoder, this, &WebPage::cancelComposition);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::GetMarkedRange::name()) {
        IPC::handleMessage<Messages::WebPage::GetMarkedRange>(decoder, *replyEncoder, this, &WebPage::getMarkedRange);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::GetSelectedRange::name()) {
        IPC::handleMessage<Messages::WebPage::GetSelectedRange>(decoder, *replyEncoder, this, &WebPage::getSelectedRange);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::GetAttributedSubstringFromRange::name()) {
        IPC::handleMessage<Messages::WebPage::GetAttributedSubstringFromRange>(decoder, *replyEncoder, this, &WebPage::getAttributedSubstringFromRange);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::CharacterIndexForPoint::name()) {
        IPC::handleMessage<Messages::WebPage::CharacterIndexForPoint>(decoder, *replyEncoder, this, &WebPage::characterIndexForPoint);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::FirstRectForCharacterRange::name()) {
        IPC::handleMessage<Messages::WebPage::FirstRectForCharacterRange>(decoder, *replyEncoder, this, &WebPage::firstRectForCharacterRange);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::ExecuteKeypressCommands::name()) {
        IPC::handleMessage<Messages::WebPage::ExecuteKeypressCommands>(decoder, *replyEncoder, this, &WebPage::executeKeypressCommands);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::ShouldDelayWindowOrderingEvent::name()) {
        IPC::handleMessage<Messages::WebPage::ShouldDelayWindowOrderingEvent>(decoder, *replyEncoder, this, &WebPage::shouldDelayWindowOrderingEvent);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::AcceptsFirstMouse::name()) {
        IPC::handleMessage<Messages::WebPage::AcceptsFirstMouse>(decoder, *replyEncoder, this, &WebPage::acceptsFirstMouse);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::WebPage::InsertDictatedText::name()) {
        IPC::handleMessage<Messages::WebPage::InsertDictatedText>(decoder, *replyEncoder, this, &WebPage::insertDictatedText);
        return;
    }
#endif
#if PLATFORM(MAC) && !PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::InsertText::name()) {
        IPC::handleMessage<Messages::WebPage::InsertText>(decoder, *replyEncoder, this, &WebPage::insertText);
        return;
    }
#endif
#if PLATFORM(MAC) && !PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::SetComposition::name()) {
        IPC::handleMessage<Messages::WebPage::SetComposition>(decoder, *replyEncoder, this, &WebPage::setComposition);
        return;
    }
#endif
#if PLATFORM(MAC) && !PLATFORM(IOS)
    if (decoder.messageName() == Messages::WebPage::ConfirmComposition::name()) {
        IPC::handleMessage<Messages::WebPage::ConfirmComposition>(decoder, *replyEncoder, this, &WebPage::confirmComposition);
        return;
    }
#endif
    ASSERT_NOT_REACHED();
}

} // namespace WebKit
